@@ -2,6 +2,10 @@
 
 /* test when no option is specified but the default ones */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 
