@@ -2,6 +2,10 @@
 
 /* test redefinition of help and version */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 
